@@ -67,12 +67,19 @@ L<IO::Handle> object C<< $fh >>.
 		my $io		= shift;
 		my $iter	= shift;
 		
-		my @vars	= @{ $iter->variables };
-		my $tb = Text::Table->new(@vars);
+		my @vars;
+		if ($iter->does('Attean::API::ResultOrTermIterator')) {
+			@vars	= @{ $iter->variables };
+		} elsif ($iter->does('Attean::API::TripleIterator')) {
+			@vars	= qw(subject predicate object);
+		} else {
+			@vars	= qw(subject predicate object graph);
+		}
 		
+		my $tb = Text::Table->new(@vars);
 		my @rows;
 		while (my $t = $iter->next()) {
-			my @strings	= map { blessed($_) ? $_->ntriples_string : '' } map { $t->value($_) } @vars;
+			my @strings	= map { blessed($_) ? $_->as_string : '' } map { eval { $t->value($_) } } @vars;
 			push(@rows, \@strings);
 		}
 		$tb->load(@rows);
